@@ -173,6 +173,9 @@ class DatabaseConfig:
         #: Database Configuration
         self.rdsCa = None
 
+        #: Database Configuration
+        self.sslMode = None
+
     @classmethod
     def dictToObject(cls, dict):
         if dict is None:
@@ -194,6 +197,8 @@ class DatabaseConfig:
         obj.adminPassword = dict.get('adminPassword', None)
 
         obj.rdsCa = dict.get('rdsCa', None)
+
+        obj.sslMode = dict.get('sslMode', None)
         return obj
 
 
@@ -469,6 +474,9 @@ class ObjectStoreBucket:
         #: Object Storage Bucket
         self.secretKey = None
 
+        #: Object Storage Bucket
+        self.region = None
+
         #: Object Storage Bucket
         self.requestedName = None
 
@@ -485,6 +493,8 @@ class ObjectStoreBucket:
 
         obj.secretKey = dict.get('secretKey', None)
 
+        obj.region = dict.get('region', None)
+
         obj.requestedName = dict.get('requestedName', None)
 
         obj.name = dict.get('name', None)
